@@ -5,6 +5,7 @@ use warnings FATAL => 'all';
 use Moo;
 use JSON::Any;
 use LWP::UserAgent;
+use URI::Escape qw(uri_escape);
 use Carp qw(croak);
 
 =head1 NAME
@@ -13,7 +14,7 @@ WebService::JotForm - Perl interface to JotForm's API -- currently only the read
 
 =head1 VERSION
 
-Version 0.003
+Version 0.004
 
 =head1 SYNOPSIS
 	
@@ -50,7 +51,7 @@ More information on tokens is available in the L<JotForm API Documentation|http:
 
 =cut
 
-our $VERSION = '0.003';
+our $VERSION = '0.004';
 
 has 'apiKey'  		=> ( is => 'ro', required => 1);
 has 'apiBase' 		=> ( is => 'ro', default => 'https://api.jotform.com');
@@ -146,8 +147,9 @@ TODO -- document additional optional params
 =cut
 
 sub get_user_submissions {
-	my $self = shift;
-	return $self->_get("user/submissions");
+	my ($self, $params) = @_;
+	$params ||= {};
+	return $self->_get("user/submissions", $params);
 }
 
 =head2 get_user_subusers()
@@ -436,7 +438,7 @@ sub _gen_request_url {
 	my ($self, $path, $params) = @_;
 	my $url = join("/", $self->apiBase, $self->apiVersion, $path) . "?apiKey=" .$self->apiKey;
 	foreach my $param (keys %$params) {
-		$url .= "&$param=$params->{$param}";
+		$url .= "&".uri_escape($param) ."=". uri_escape($params->{$param});
 	}
 	return $url;
 } 
